from cml.domain.reconstruction import (
    split,
    valid_reconstructed,
    Metadata,
    PragmaticMachineLearningModel,
    InterimPragmatic)


def reconstruct_in_parallel(*args):
    count, model, learnblock, level, abv, settings = args[0]
    train, test = split(learnblock, settings.reliability_sample)
    train_X = train.as_numpy_array()
    train_Y = [label for label in train.get_column("Z")]
    test_X = test.as_numpy_array()
    trained_model = model.train(train_X, train_Y)
    if valid_reconstructed(trained_model, "conceptual", settings):
        zeta = ".".join([
            abv, str(level), learnblock.subject
        ])

        meta = Metadata(abv, level, count, learnblock.indices(),
                        learnblock.columns(), learnblock.get_column("Z"),
                        learnblock.min_timestamp(), learnblock.max_timestamp(),
                        (model.subject,), (zeta,))
        pragmatic = PragmaticMachineLearningModel(meta, trained_model, learnblock)
        predictions = trained_model.predict(test_X)
        return InterimPragmatic(pragmatic, predictions, learnblock)

    return None, None
